SystemOrganization addCategory: #'EyeSee-Tests-Core'!

TestCase subclass: #ESAbstractAxisDecoratorTest
	instanceVariableNames: 'values axis axisDecorator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESAbstractAxisDecoratorTest methodsFor: 'testing' stamp: 'TudorGirba 4/6/2011 09:15'!
setUp
	
	values := #(1 2 3 4).
	axis := ESAxis new initialize.
	axis
		setStart: 0 @ 0
		setEnd: 100 @ 0.
	axis values: values.
	axis maxValue: 4.
	axisDecorator := ESAbstractAxisDecorator newWith: axis! !

!ESAbstractAxisDecoratorTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:25'!
testCalculatePoint
	
	self assert: (axisDecorator calculatePoint: 4) = (axis calculatePoint: 4)! !

!ESAbstractAxisDecoratorTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:25'!
testCopy
	
	| copy |
	copy := axisDecorator copy.
	self assert: copy ~= axisDecorator.
	self assert: copy anAxis ~= axis.
	self assert: copy values = axisDecorator values.
	self assert: copy start = axisDecorator start.
	self assert: copy end = axisDecorator end.
	copy end: 1 @ 0.
	self assert: copy end ~= axisDecorator end.
	self assert: copy values = axisDecorator values.
	self assert: copy start = axisDecorator start.
	copy values: #(1 2 3).
	self assert: copy end ~= axisDecorator end.
	self assert: copy values ~= axisDecorator values.
	self assert: copy start = axisDecorator start! !

!ESAbstractAxisDecoratorTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:25'!
testGetters
	
	self assert: axisDecorator anAxis = axis.
	self assert: axisDecorator end = axis end.
	self assert: axisDecorator start = axis start.
	self assert: axisDecorator label = axis label.
	self assert: axisDecorator length = axis length.
	self assert: axisDecorator minValue = axis minValue.
	self assert: axisDecorator maxValue = axis maxValue.
	self assert: axisDecorator scaleFactor = axis scaleFactor.
	self assert: axisDecorator values = axis values! !

!ESAbstractAxisDecoratorTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:25'!
testNormalVector
	
	self
		assert:
			(axisDecorator
				calculateNormalVectorAt: 0 @ 0
				ofLenght: 0) = (0 @ 0).
	self
		assert:
			(axisDecorator
				calculateNormalVectorAt: 100 @ 0
				ofLenght: 0) = (100 @ 0).
	self
		assert:
			((axisDecorator
				calculateNormalVectorAt: 100 @ 0
				ofLenght: 100) dist: 100 @ 100) asInteger = 0.
	self
		assert:
			((axisDecorator
				calculateNormalVectorAt: 0 @ 100
				ofLenght: 100) dist: -100 @ 100) asInteger = 0! !

TestCase subclass: #ESAxisTest
	instanceVariableNames: 'axis values'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESAxisTest methodsFor: 'testing' stamp: 'TudorGirba 4/6/2011 09:15'!
setUp
	
	values := #(1 2 3 4).
	axis := ESAxis new initialize.
	axis maxValue: 4.
	axis
		setStart: 0 @ 0
		setEnd: 100 @ 0.
	axis values: values! !

!ESAxisTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:14'!
testCalculatePoint
	
	self assert: (axis calculatePoint: 3) = (75 @ 0).
	self assert: (axis calculatePoint: 0) = (0 @ 0).
	self assert: (axis calculatePoint: 4) = (100 @ 0)! !

!ESAxisTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:14'!
testLength
	
	self assert: axis length = 100! !

!ESAxisTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:14'!
testMaxMin
	
	self assert: axis maxValue = 4.
	self assert: axis minValue = 0! !

!ESAxisTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:15'!
testScaleFactor
	
	self assert: axis scaleFactor = 25! !

!ESAxisTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:15'!
testValues
	
	self assert: (axis values collect: #model) = values! !

TestCase subclass: #ESCanvasTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESCanvasTest methodsFor: 'tests' stamp: 'TudorGirba 4/17/2011 23:42'!
testDefaultAnnouncer
	self assert: (ESCanvas new announcer isKindOf: ESAnnouncer)! !

TestCase subclass: #ESDummyFactoryTest
	instanceVariableNames: 'xValues yValues colors groups factory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESDummyFactoryTest methodsFor: 'testing' stamp: 'TudorGirba 4/5/2011 22:36'!
setUp
	
	xValues := #(1 2 3).
	yValues := #(4 5 6).
	colors := #(#A #B #C).
	groups := #(#D #D #A).
	factory := ESDummyFactory new.
	factory xValues: xValues.
	factory yValues: yValues.
	factory colors: colors.
	factory groupIds: groups! !

!ESDummyFactoryTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:26'!
testDummies
	
	| dummies |
	dummies := factory buildDummies.
	dummies
		doWithIndex:
			[:each :i | 
			self assert: each xValue = (xValues at: i).
			self assert: each yValue = (yValues at: i).
			self assert: each color = (colors at: i).
			self assert: each groupId = (groups at: i)]! !

TestCase subclass: #ESExamplesTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESExamplesTest methodsFor: 'tests' stamp: 'TudorGirba 9/9/2012 00:39'!
testSmoke
	(ESExamples selectors select: [:each | each endsWith: 'With:']) do: [:each |
		self 
			shouldnt: [ 
				| window renderer |
				renderer := ESDiagramRenderer new.
				ESExamples new perform: each with: renderer.
				window := renderer open.
				window delete ]  
			raise: Error ]! !

TestCase subclass: #ESMalMatrixTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESMalMatrixTest commentStamp: 'AlexandreBergel 11/4/2011 15:14' prior: 0!
Testing the matrixes!

!ESMalMatrixTest methodsFor: 'tests' stamp: 'TudorGirba 11/16/2011 10:17'!
testHashShouldNotRaiseError
	| matrix |
	matrix := ESMalArrayMatrix rows: 10 columns: 10 withAll: 10.
	self shouldnt: [matrix hash] raise: Error! !

!ESMalMatrixTest methodsFor: 'tests' stamp: 'TudorGirba 11/16/2011 10:13'!
testInstantiationDoesNotProduceError
	ESMalMatrix allSubclasses do: [ :cls |
		self shouldnt: [cls new] raise: Error 
	] ! !

TestCase subclass: #ESPieDiagramTest
	instanceVariableNames: 'chart1'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESPieDiagramTest methodsFor: 'running' stamp: 'AndreHora 4/1/2012 21:16'!
setUp

	chart1 := ESPieDiagram new.
	chart1 radius: 1.
	chart1 xPadding: 0.
	chart1 yPadding: 0! !

!ESPieDiagramTest methodsFor: 'tests' stamp: 'AndreHora 10/13/2011 12:37'!
testCalculateArcPointsFromTo
	
	| arcPoints |
	
	"testing the unit circle"
	
	" ----- 0 to 90 degree -----"
	chart1 segmentEachDegree: 5.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 19.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"90 degree"
	self assert: arcPoints last = (0@1).

	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 10.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"90 degree"
	self assert: arcPoints last = (0@1).

	chart1 segmentEachDegree: 15.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 7.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"90 degree"
	self assert: arcPoints last = (0@1).

	chart1 segmentEachDegree: 30.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 4.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"90 degree"
	self assert: arcPoints last = (0@1).

	" ----- 0 to 180 degree -----"
	chart1 segmentEachDegree: 5.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 37.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"180 degree"
	self assert: arcPoints last = (-1@0).

	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 19.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"180 degree"
	self assert: arcPoints last = (-1@0).

	chart1 segmentEachDegree: 15.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 13.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"180 degree"
	self assert: arcPoints last = (-1@0).

	chart1 segmentEachDegree: 30.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 7.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"180 degree"
	self assert: arcPoints last = (-1@0).

	" ----- 0 to 270 degree -----"
	chart1 segmentEachDegree: 5.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 55.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"270 degree"
	self assert: arcPoints last = (0@ -1).

	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 28.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"270 degree"
	self assert: arcPoints last = (0@ -1).

	chart1 segmentEachDegree: 15.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 19.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"270 degree"
	self assert: arcPoints last = (0@ -1).

	chart1 segmentEachDegree: 30.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 10.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"270 degree"
	self assert: arcPoints last = (0@ -1).
	
	" ----- 0 to 360 degree -----"
	chart1 segmentEachDegree: 5.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 73.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"360 degree"
	self assert: arcPoints first = (1@0).

	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 37.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"360 degree"
	self assert: arcPoints first = (1@0).

	chart1 segmentEachDegree: 15.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 25.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"360 degree"
	self assert: arcPoints first = (1@0).

	chart1 segmentEachDegree: 30.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 13.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"360 degree"
	self assert: arcPoints first = (1@0).

	" ----- 90 to 180 degree -----"
	chart1 segmentEachDegree: 5.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 19.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"180 degree"
	self assert: arcPoints last = (-1@0).

	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 10.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"180 degree"
	self assert: arcPoints last = (-1@0).

	chart1 segmentEachDegree: 15.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 7.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"180 degree"
	self assert: arcPoints last = (-1@0).

	" ----- 90 to 270 degree -----"
	chart1 segmentEachDegree: 5.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 37.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"270 degree"
	self assert: arcPoints last = (0@ -1).

	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 19.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"270 degree"
	self assert: arcPoints last = (0@ -1).

	chart1 segmentEachDegree: 15.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 13.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"270 degree"
	self assert: arcPoints last = (0@ -1).

	chart1 segmentEachDegree: 30.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 7.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"270 degree"
	self assert: arcPoints last = (0@ -1).


	" ----- 90 to 360 degree -----"
	chart1 segmentEachDegree: 5.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 55.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"360 degree"
	self assert: arcPoints last = (1@0).

	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 28.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"360 degree"
	self assert: arcPoints last = (1@0).

	chart1 segmentEachDegree: 15.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 19.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"360 degree"
	self assert: arcPoints last = (1@0).

	chart1 segmentEachDegree: 30.
	arcPoints := chart1 calculateArcPointsFrom: 90 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 10.
	"90 dregree"
	self assert: arcPoints first = (0@1).
	"360 degree"
	self assert: arcPoints last = (1@0).
	
	" ----- others -----"
	chart1 segmentEachDegree: 89.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 3.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"90 degree"
	self assert: arcPoints last = (0@1).

	chart1 segmentEachDegree: 90.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 2.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"90 degree"
	self assert: arcPoints last = (0@1).

	chart1 segmentEachDegree: 91.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	self assert: arcPoints size = 2.
	"0 dregree"
	self assert: arcPoints first = (1@0).
	"90 degree"
	self assert: arcPoints last = (0@1).! !

!ESPieDiagramTest methodsFor: 'tests' stamp: 'AndreHora 10/13/2011 12:36'!
testCalculateDegreeFor

	chart1 models: #(25 25 50).
	self assert: (chart1 calculateDegreeFor: chart1 models first) = 90.
	self assert: (chart1 calculateDegreeFor: chart1 models second) = 90.
	self assert: (chart1 calculateDegreeFor: chart1 models third) = 180.

	chart1 models: #(12.5 12.5 50 25).
	self assert: (chart1 calculateDegreeFor: chart1 models first) = 45.
	self assert: (chart1 calculateDegreeFor: chart1 models second) = 45.
	self assert: (chart1 calculateDegreeFor: chart1 models third) = 180.
	self assert: (chart1 calculateDegreeFor: chart1 models fourth) = 90.! !

!ESPieDiagramTest methodsFor: 'tests' stamp: 'AndreHora 10/13/2011 12:55'!
testTransformPoint

	"with radius = 1, the starting point is p(0,1)"
	
	| arcPoints |

	" ----- 0 to 90 degree -----"
	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 90.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	"0 dregree"
	self assert: (chart1 transformPoint: arcPoints first) = (0@1).
	"90 degree"
	self assert: (chart1 transformPoint: arcPoints last) = (1@0).

	" ----- 0 to 180 degree -----"
	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 180.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	"0 dregree"
	self assert: (chart1 transformPoint: arcPoints first) = (0@1).
	"180 degree"
	self assert: (chart1 transformPoint: arcPoints last) = (2@1).

	" ----- 0 to 270 degree -----"
	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 270.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	"0 dregree"
	self assert: (chart1 transformPoint: arcPoints first) = (0@1).
	"270 degree"
	self assert: (chart1 transformPoint: arcPoints last) = (1@2).

	" ----- 0 to 360 degree -----"
	chart1 segmentEachDegree: 10.
	arcPoints := chart1 calculateArcPointsFrom: 0 to: 360.
	arcPoints := arcPoints collect: [ :each | self trunctatePoint: each ].
	"0 dregree"
	self assert: (chart1 transformPoint: arcPoints first) = (0@1).
	"360 degree"
	self assert: (chart1 transformPoint: arcPoints last) = (0@1).
	! !

!ESPieDiagramTest methodsFor: 'private' stamp: 'AndreHora 10/13/2011 11:46'!
trunctatePoint: aPoint

	^ aPoint x asTruncatedFloat @ aPoint y asTruncatedFloat! !

TestCase subclass: #ESVerticalBarDiagramTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESVerticalBarDiagramTest methodsFor: 'tests' stamp: 'TudorGirba 10/1/2012 13:07'!
testElementsHaveTheCorrectModels
	| model diagram |
	model := #(fourty two).
	diagram := ESVerticalBarDiagram new.
	diagram 
		models: model;
		y: #size;
		setup.
	self assert: diagram elements size = model size.
	self assert: diagram elements first model equals: model first.
	self assert: diagram elements last model equals: model last! !

TestCase subclass: #ESVerticalBarTest
	instanceVariableNames: 'vBar diag dm diag2 model2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESVerticalBarTest methodsFor: 'testing' stamp: 'TudorGirba 4/6/2011 09:15'!
setUp
	
	diag := ESVerticalBarDiagram new.
	diag y: [:each | each].
	diag
		models:
			((OrderedCollection new)
				add: 1;
				add: 0;
				add: 3;
				yourself).
	diag setup.
																										
	diag2 := ESVerticalBarDiagram new.
	diag2 y: [:each | each].
	diag2 preferredAxisMaxY: 5.
	model2 := Array with: 1 with: 0 with: 3.
	diag2 models: model2.
	diag2 setup! !

!ESVerticalBarTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:30'!
testVerticalBarChart
	
	| yunit xunit |
	
	yunit := diag contentHeight / diag elements size asFloat.
	xunit := diag contentWidth / diag elements size asFloat.
	self assert: 3 * yunit = diag contentHeight.
	self assert: diag elements size = 3.
	self assert: (diag elements at: 1) height = yunit.
	self assert: (diag elements at: 2) height = 0.
	self assert: (diag elements at: 3) height = diag contentHeight.
	self
		assert:
			(diag elements at: 1) width rounded = (diag barFraction * xunit) rounded.
	self
		assert:
			(diag elements at: 2) width rounded = (diag barFraction * xunit) rounded.
	self
		assert:
			(diag elements at: 3) width rounded = (diag barFraction * xunit) rounded! !

!ESVerticalBarTest methodsFor: 'testing' stamp: 'AndreHora 3/13/2011 14:30'!
testVerticalBarChart2
	
	| yunit |

	yunit := diag2 contentHeight / diag2 preferredAxisMaxY asFloat.
	self assert: 5 * yunit = diag2 contentHeight.
	self assert: diag2 elements size = model2 size.
	self assert: (diag2 elements at: 1) height = yunit.
	self assert: (diag2 elements at: 2) height = 0.
	self assert: (diag2 elements at: 3) height = ((model2 at: 3) * yunit).
	self assert: (diag2 elements at: 3) height ~= diag2 contentHeight.
	self assert: diag2 getMaxY = 5.
	self assert: 5 = diag2 preferredAxisMaxY! !

Object subclass: #ESContributor
	instanceVariableNames: 'name numberOfCommits team loc impactOnSystem'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
impactOnSystem
	
	^impactOnSystem! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
impactOnSystem: anObject
	
	impactOnSystem := anObject! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
loc
	
	^loc! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
loc: anObject
	
	loc := anObject! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
name
	
	^name! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
name: anObject
	
	name := anObject! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
numberOfCommits
	
	^numberOfCommits! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
numberOfCommits: anObject
	
	numberOfCommits := anObject! !

!ESContributor methodsFor: 'printing' stamp: 'TudorGirba 10/1/2012 09:06'!
printOn: aStream 
	super printOn: aStream.
	aStream nextPutAll: self name! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
team
	
	^team! !

!ESContributor methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
team: anObject
	
	team := anObject! !

Object subclass: #ESDummyFactory
	instanceVariableNames: 'xValues yValues colors groupIds count identifiers histories'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESDummyFactory methodsFor: 'creation' stamp: 'TudorGirba 4/5/2011 22:36'!
buildDummies
	
	| dummies |
	dummies := OrderedCollection new.
	self checkValues.
	(1 to: self count)
		do:
			[:i | 
			dummies
				add:
					((ESDummyValue new)
						xValue: (self xValues ifNotNil: [self xValues at: i]);
						yValue: (self yValues ifNotNil: [self yValues at: i]);
						color: (self colors ifNotNil: [self colors at: i]);
						groupId: (self groupIds ifNotNil: [self groupIds at: i]);
						history: (self histories ifNotNil: [self histories at: i]);
						identifier:
								(self identifiers ifNotNil: [self identifiers at: i]) yourself)].
	^dummies! !

!ESDummyFactory methodsFor: 'creation' stamp: ' 11/3/11 16:41'!
checkValues
	
	| notNilCollections |
	notNilCollections := OrderedCollection new.
	self xValues ~= nil ifTrue: [notNilCollections add: self xValues].
	self yValues ~= nil ifTrue: [notNilCollections add: self yValues].
	self colors ~= nil ifTrue: [notNilCollections add: self colors].
	self groupIds ~= nil ifTrue: [notNilCollections add: self groupIds].
	self histories ~= nil ifTrue: [notNilCollections add: self histories].
	self identifiers ~= nil ifTrue: [notNilCollections add: self identifiers].
	self count: notNilCollections first size.
	notNilCollections do: [:each | [each size = self count] assert]! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
colors
	
	^colors! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
colors: anObject
	
	colors := anObject! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
count
	
	^count! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
count: anObject
	
	count := anObject! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
groupIds
	
	^groupIds! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
groupIds: anObject
	
	groupIds := anObject! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
histories
	
	^histories! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
histories: anObject
	
	histories := anObject! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
identifiers
	
	^identifiers! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
identifiers: anObject
	
	identifiers := anObject! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
xValues
	
	^xValues! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
xValues: anObject
	
	xValues := anObject! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
yValues
	
	^yValues! !

!ESDummyFactory methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
yValues: anObject
	
	yValues := anObject! !

Object subclass: #ESDummyValue
	instanceVariableNames: 'xValue yValue color groupId identifier history'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
color
	
	^color! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
color: anObject
	
	color := anObject! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
groupId
	
	^groupId! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
groupId: anObject
	
	groupId := anObject! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
history
	
	^history! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
history: anObject
	
	history := anObject! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
identifier
	
	^identifier! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
identifier: anObject
	
	identifier := anObject! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
xValue
	
	^xValue! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
xValue: anObject
	
	xValue := anObject! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
yValue
	
	^yValue! !

!ESDummyValue methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
yValue: anObject
	
	yValue := anObject! !

Object subclass: #ESExamples
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 9/7/2012 13:12'!
chartBarCompositeDiagram
	"self new chartBarCompositeDiagram"

	| renderer |
	renderer := ESDiagramRenderer new.
	self chartBarCompositeDiagramWith: renderer.
	^ renderer open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:44'!
chartBarCompositeDiagram2
	"self new barCompositeDiagram2"

	| renderer |
	renderer := ESDiagramRenderer new.
	self chartCompositeBarDiagram2With: renderer.
	^ renderer open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:45'!
chartBarCompositeDiagram3
	"self new composedBarDiagram"

	| renderer |
	renderer := ESDiagramRenderer new.
	self chartBarCompositeDiagram3With: renderer.
	^ renderer open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:45'!
chartBarCompositeDiagram3With: renderer
	| diag diag2 |
	diag := ESVerticalBarDiagram new
		identifier: #name;
		rotatedLabels: true;
		y: #numberOfCommits;
		leftGap: 0.2;
		rightGap: 0.5;
		regularAxis;
		models: self contributors2;
		yAxisLabel: 'Commits';
		yourself.
	diag2 := ESVerticalBarDiagram new
		y: #loc;
		regularAxis;
		leftGap: 0.5;
		rightGap: 0.2;
		rightYAxis;
		defaultColor: Color green;
		axisColor: Color green;
		yAxisLabel: 'LoC';
		models: self contributors2;
		yourself.
	renderer compositeDiagram
		add: diag;
		add: diag2;
		yPadding: 30;
		height: 400;
		width: 500! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 9/7/2012 13:12'!
chartBarCompositeDiagramWith: diag3
	| diag diag2 |
	diag := ESVerticalBarDiagram new
		identifier: #name;
		y: #numberOfCommits;
		yAxisLabel: 'Commits';
		regularAxis;
		defaultColor: Color lightGray;
		models: self contributors2;
		rotatedLabels: true;
		yourself.
	diag2 := ESVerticalBarDiagram new
		y: #loc;
		regularAxis;
		yAxisLabel: 'LoC';
		gapFraction: 2 / 3;
		rightYAxis;
		defaultColor: Color green;
		axisColor: Color green;
		models: self contributors2;
		yourself.
	diag3 compositeDiagram
		add: diag;
		add: diag2;
		height: 400;
		width: 500! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:44'!
chartCompositeBarDiagram2With: renderer
	| diag diag2 |
	diag := ESVerticalBarDiagram new
		identifier: #name;
		rotatedLabels: true;
		y: #numberOfCommits;
		leftGap: 0.2;
		rightGap: 0.5;
		regularAxis;
		defaultColor: Color blue;
		models: self contributors2;
		yAxisLabel: 'Commits';
		yourself.
	diag2 := ESVerticalBarDiagram new
		y: #loc;
		regularAxis;
		leftGap: 0.5;
		rightGap: 0.2;
		rightYAxis;
		defaultColor: Color green;
		axisColor: Color green;
		yAxisLabel: 'LoC';
		models: self contributors2;
		yourself.
	renderer compositeDiagram
		add: diag;
		add: diag2;
		height: 300;
		width: 500! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:51'!
chartDeviation
	"self new deviation"

	| renderer |
	renderer := ESDiagramRenderer new.
	self chartDeviationWith: renderer.
	^ renderer open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:45'!
chartDeviationDiagram
	"self new chartDeviationDiagram"
	
	| diag |
	diag := ESDiagramRenderer new.
	self chartDeviationDiagramWith: diag.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:49'!
chartDeviationDiagramWith: diag	
	(diag deviationDiagram)
		y: #loc;
		identifier: #name;
		width: 500;
		height: 400;
		deviationValue: 3000;
		highlightAboveDeviation;
		labelsInPercent;
		valueAxis;
		rotatedLabels: true;
		models: self contributors2! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 9/7/2012 10:45'!
chartDeviationDiagramWithInteraction
	"self new chartDeviationDiagramWithInteraction"

	| diag |
	diag := ESDiagramRenderer new.
	self chartDeviationDiagramWithInteractionWith: diag.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 9/7/2012 10:45'!
chartDeviationDiagramWithInteractionWith: diag
	diag deviationDiagram
		y: #loc;
		identifier: #name;
		width: 500;
		height: 400;
		deviationValue: 3000;
		highlightAboveDeviation;
		labelsInPercent;
		valueAxis;
		rotatedLabels: true;
		models: self contributors2.
	diag interaction
		strongHighlightWhenOver;
		popupText: #name! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:50'!
chartDeviationWith: diag
	| factory |
	factory := ESDummyFactory new.
	factory yValues: #(123 154 132 223 211 301 212 312 212 401 148 233 112 434 223 177).
	factory
		colors:
			#('Team 1' 'Team 1' 'Team 1' 'Team 2' 'Team 2' 'Team 2' 'Team 2' 'Team 3' 'Team 3' 'Team 1' 'Team 1' 'Team 2' 'Team 1' 'Team 3' 'Team 1' 'Team 1').
	factory identifiers: #(#A #B #C #D #E #F #G #H #I #J #K #L #M #N #O #P).
	diag deviationDiagram
		y: #yValue;
		width: 600;
		height: 400;
		deviationDescription: 'avg 2006';
		identifier: #identifier;
		valueAxis;
		strongColors;
		models: factory buildDummies! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 08:08'!
chartPieDiagramWithHighlightAndPopupWith: diag
	diag pieDiagram
		borderWidth: 1;
		radius: 200;
		models: #(30 10 20 40);
		defaultColor: Color white.
	diag interaction
		strongHighlightWhenOver;
		popupText! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:52'!
chartScatterPlot1
	"self new scatterPlot1"

	| diag |
	diag := ESDiagramRenderer new.
	self chartScatterplot1With: diag.	"shape: #team;"
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:52'!
chartScatterPlot2
	"self new scatterPlot2"

	| diag |
	diag := ESDiagramRenderer new.
	self chartScatterplot2With: diag.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:53'!
chartScatterPlot3
	"self new scatterPlot3"

	| diag |
	diag := ESDiagramRenderer new.
	self chartScatterplot3With: diag.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:54'!
chartScatterPlot4
	"self new scatterPlot4"

	| diag |
	diag := ESDiagramRenderer new.
	self chartScatterplot4With: diag.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:54'!
chartScatterPlot5
	"Scatterplot displaying only a selected area"
	"self new scatterPlot5"

	| diag |
	diag := ESDiagramRenderer new.
	self chartScatterplot5With: diag.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 08:05'!
chartScatterplot1With: diag
	diag scatterplot
		y: #numberOfCommits;
		x: #loc;
		color: #team;
		mediumObjects;
		width: 300;
		height: 300;
		valueAxis;
		rotatedLabels: true;
		models: self contributors2	"shape: #team;"! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:52'!
chartScatterplot2With: diag
	diag scatterplot
		y: #numberOfCommits;
		x: #loc;
		shape: #team;
		width: 400;
		height: 400;
		strokedShapes;
		mediumObjects;
		boxPlotAxis;
		rotatedLabels: true;
		models: self contributors2! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:53'!
chartScatterplot3With: diag
	| factory |
	factory := ESDummyFactory new.
	factory xValues: #(100 15 20 30 41 45.4 42 43 45 50 60 120 23 42 200).
	factory yValues: #(100 35 15 30 60 30 30 43 45 50 60 150 23 64 160).
	factory colors: #(1 1 2 3 3 1 2 2 2 2 1 2 4 3 3).
	diag scatterplot
		y: #yValue;
		x: #xValue;
		color: #color;
		bigObjects;
		grayShades;
		rectangles;
		width: 400;
		height: 400;
		rangeAxis;
		rotatedLabels: false;
		models: factory buildDummies! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:53'!
chartScatterplot4With: diag
	| factory |
	factory := ESDummyFactory new.
	factory xValues: #(30 15 20 30 41 41.4 42 43 45 50 40 40 60 30 45).
	factory yValues: #(30 13 15 30 60 30 30 43 45 50 60 60 60 20 45).
	factory colors: #(1 1 2 3 3 1 2 2 2 2 2 2 1 1 1).
	diag scatterplot
		width: 300;
		height: 300;
		y: #yValue;
		x: #xValue;
		shape: #color;
		color: #color;
		boxPlotAxis;
		rotatedLabels: false;
		models: factory buildDummies! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 22:54'!
chartScatterplot5With: diag
	| factory |
	factory := ESDummyFactory new.
	factory xValues: #(149 10 15 30 41 41.4 42 43 45 50 60 120 200 201 12 51 32).
	factory yValues: #(149 13 20 30 60 30 30 43 45 50 60 150 160 161 100 79 52).
	factory colors: #(1 1 2 1 1 1 2 2 2 2 1 2 2 1 2 1 1).
	diag scatterplot
		y: #yValue;
		x: #xValue;
		shape: #color;
		color: #color;
		displayLegend: false;
		preferredAxisMinX: 50;
		preferredAxisMaxX: 150;
		preferredAxisMinY: 50;
		preferredAxisMaxY: 150;
		width: 400;
		height: 400;
		bigObjects;
		strongColors;
		valueAxis;
		rotatedLabels: false;
		models: factory buildDummies! !

!ESExamples methodsFor: 'models' stamp: 'AndreHora 4/11/2011 22:48'!
collectionExample1
	"self new collectionExample1"
	
	^ #(1 1 3 4 2 1 3) openPlotWith: #(3 2 1 3 5 6 5)! !

!ESExamples methodsFor: 'models' stamp: 'TudorGirba 4/6/2011 09:24'!
collectionExample2
	"self new collectionExample2"
	
	^ (OrderedCollection new)
		add: 0 @ 0;
		add: 0 @ 3;
		add: 1 @ 5;
		add: 4 @ 1;
		add: 2 @ 4;
		openScatterPlot! !

!ESExamples methodsFor: 'models' stamp: 'AlexandreBergel 12/7/2011 09:41'!
collectionExample3
	"self new collectionExample3"
	
	^ #(1 1 3 4 2 1 3) openPlot! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/15/2011 16:59'!
compositeDiagram
	"self new compositeDiagram"
	
	| diag1 factory diag2 diag3 factory2 |
	factory := ESDummyFactory new.
	factory yValues: #(30 5 15 20 28 24 22 26).
	factory2 := ESDummyFactory new.
	factory2 yValues: #(14 24 21 11 22 13 43 21).
	diag1 := (ESDiagramRenderer new lineDiagram)
		y: #yValue;
		models: factory buildDummies;
		regularAxis;
		rightYAxis;
		defaultColor: Color blue;
		axisColor: Color blue;
		yourself.
	diag2 := (ESDiagramRenderer new verticalBarDiagram)
		y: #yValue;
		regularAxis;
		axisColor: Color darkGray;
		defaultColor: Color darkGray;
		models: factory2 buildDummies;
		yourself.
	diag3 := ESDiagramRenderer new.
	(diag3 compositeDiagram)
		add: diag2;
		add: diag1.
	^ diag3 open! !

!ESExamples methodsFor: 'models' stamp: 'TudorGirba 4/5/2011 22:36'!
contributors
	
	| contributors |
	contributors := OrderedCollection new.
	contributors
		add:
				((ESContributor new)
						name: 'Jack';
						numberOfCommits: 14;
						team: 'one';
						loc: 3020;
						impactOnSystem: 5);
		add:
				((ESContributor new)
						name: 'Joe';
						numberOfCommits: 23;
						team: 'one';
						loc: 3402;
						impactOnSystem: 10);
		add:
				((ESContributor new)
						name: 'Tom';
						numberOfCommits: 31;
						team: 'two';
						loc: 3800;
						impactOnSystem: 25);
		add:
				((ESContributor new)
						name: 'Matt';
						numberOfCommits: 13;
						team: 'two';
						loc: 2904;
						impactOnSystem: 30);
		add:
				((ESContributor new)
						name: 'Julian';
						numberOfCommits: 6;
						team: 'three';
						loc: 2732;
						impactOnSystem: 30).
	^contributors! !

!ESExamples methodsFor: 'models' stamp: 'TudorGirba 4/5/2011 22:36'!
contributors2
	
	| contributors |
	contributors := OrderedCollection new.
	contributors
		add:
				((ESContributor new)
						name: 'Jack';
						numberOfCommits: 20;
						team: 'one';
						loc: 3020);
		add:
				((ESContributor new)
						name: 'Joe';
						numberOfCommits: 23;
						team: 'one';
						loc: 3902);
		add:
				((ESContributor new)
						name: 'Tom';
						numberOfCommits: 31;
						team: 'two';
						loc: 3800);
		add:
				((ESContributor new)
						name: 'Matt';
						numberOfCommits: 13;
						team: 'two';
						loc: 2506);
		add:
				((ESContributor new)
						name: 'Julian';
						numberOfCommits: 6;
						team: 'three';
						loc: 4100);
		add:
				((ESContributor new)
						name: 'Mark';
						numberOfCommits: 33;
						team: 'one';
						loc: 2312);
		add:
				((ESContributor new)
						name: 'Simon';
						numberOfCommits: 25;
						team: 'one';
						loc: 1256);
		add:
				((ESContributor new)
						name: 'Tim';
						numberOfCommits: 26;
						team: 'two';
						loc: 2350);
		add:
				((ESContributor new)
						name: 'Arnold';
						numberOfCommits: 13;
						team: 'two';
						loc: 5674);
		add:
				((ESContributor new)
						name: 'James';
						numberOfCommits: 17;
						team: 'three';
						loc: 3445);
		add:
				((ESContributor new)
						name: 'Will';
						numberOfCommits: 31;
						team: 'one';
						loc: 2765);
		add:
				((ESContributor new)
						name: 'Richard';
						numberOfCommits: 29;
						team: 'one';
						loc: 578);
		add:
				((ESContributor new)
						name: 'Marc';
						numberOfCommits: 25;
						team: 'two';
						loc: 2346);
		add:
				((ESContributor new)
						name: 'Nic';
						numberOfCommits: 7;
						team: 'two';
						loc: 1456);
		add:
				((ESContributor new)
						name: 'James';
						numberOfCommits: 5;
						team: 'three';
						loc: 760).
	^contributors	"^ (contributors sorted: #numberOfCommits) reverse."! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 16:32'!
deviationInteraction1
	"self new deviationInteraction1"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues:
			#(123 154 132 223 211 301 212 312 212 401 148 233 112 434 223 177).
	factory colors:
			#('Team 1' 'Team 1' 'Team 1' 'Team 2' 'Team 2' 'Team 2' 'Team 2' 'Team 3' 'Team 3' 'Team 1' 'Team 1' 'Team 2' 'Team 1' 'Team 3' 'Team 1' 'Team 1').
	factory identifiers: #(#A #B #C #D #E #F #G #H #I #J #K #L #M #N #O #P).
	diag := ESDiagramRenderer new.
	(diag deviationDiagram)
		y: #yValue;
		width: 600;
		height: 400;
		deviationDescription: 'avg 2006';
		identifier: #identifier;
		valueAxis;
		strongColors;
		models: factory buildDummies.

	diag interaction 
		strongHighlightWhenOver;
		popupText: #identifier.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 9/7/2012 16:03'!
drawFunction
	"self new drawFunction"

	| diag f |
	f := [ :x | x sin ].
	diag := ESDiagramRenderer new.
	diag lineDiagram
		y: f;
		yAxisLabel: 'sin(x)';
		rotatedLabels: true;
		regularAxis;
		defaultColor: Color green;
		models: (0 to: 10 by: 0.1).
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2011 15:33'!
hBarDiagram
	"self new hBarDiagram"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag horizontalBarDiagram)
		width: 300;
		height: 250;
		identifier: #name;
		deviationValue: 8;
		deviationDescription: 'avg 2006';
		x: #numberOfCommits;
		color: #team;
		useColors: {Color red. Color green. Color blue};
		regularAxis;
		rotatedLabels: true; "TODO"
		models: self contributors.	"gridLine;"

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 09:04'!
hBarDiagramInteraction1
	"self new hBarDiagramInteraction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag horizontalBarDiagram)
		width: 300;
		height: 250;
		identifier: #name;
		deviationValue: 8;
		deviationDescription: 'avg 2006';
		x: #numberOfCommits;
		color: #team;
		useColors: {Color red. Color green. Color blue};
		regularAxis;
		rotatedLabels: true; "TODO"
		models: self contributors.	"gridLine;"

	diag interaction 
		strongHighlightWhenOver;
		popupText: #name.

	^ diag open ; explore! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/9/2011 21:15'!
histo
	"self new histo"
	
	| diagram |
	diagram := ESDiagramRenderer new.
	diagram histo
		models: #(10 12 13 200 150 13 149 151);
		property: #yourself;
		numberOfIntervals: 3;
		rotatedLabels: true;  
		preferredAxisMaxY: 5;
		height: 200;
		width: 90;
		xPadding: 0;
		yPadding: 1;
		addXDecorator: ESBaseLineDecorator new;
		valueTicks;
		valueLabels;
		gridLine.
	^ diagram open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/9/2011 21:15'!
histogram
	"self new histogram"
	
	| diagram |
	diagram := ESDiagramRenderer new.
	diagram histogram
		models: #(10 12 13 200 150 13 149 151);
		property: #yourself;
		numberOfIntervals: 3;
		rotatedLabels: true;  
		preferredAxisMaxY: 20;
		height: 20;
		width: 90;
		xPadding: 0;
		yPadding: 1;
		addXDecorator: ESBaseLineDecorator new.
	^ diagram open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/6/2011 10:45'!
historyDiagram
	"self new historyDiagram"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag historyDiagram)
		dataset: #history;
		attribute: #yValue;
		regularAxis;
		displayLegend: false;
		color: #color;
		useColors: ESAbstractDiagram lightColors;
		models: self projects.
	diag interaction 
		strongHighlightWhenOver.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/6/2011 10:45'!
historyDiagram3
	"self new historyDiagram3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag historyDiagram)
		dataset: #history;
		width: 500;
		height: 400;
		attribute: #yValue;
		regularAxis;
		horizontalLegend;
		color: #color;
		useColors: ESAbstractDiagram lightColors;
		models: self projects.
	diag interaction 
		strongHighlightWhenOver.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2011 15:34'!
horizontalBarDiagram
	"self new horizontalBarDiagram"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag horizontalBarDiagram)
		identifier: #name;
		x: #numberOfCommits;
		color: #team;
		deviationValue: 20;
		regularAxis;
		rotatedLabels: true; "TODO"
		models: self contributors.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2012 18:08'!
kiviat2
	"self new kiviat2"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag kiviat)
		borderWidth: 1;
		radius: 150;
		axisLabels: {'loc'. 'nom'. 'noa'. 'ciclo'};
		models: {#(8 10 1). #(7 2 10). #(3 10 8)};
		metrics: {#first. #second. #last. [ :each | each first + 2]};
		maxs: {[ :model | 10]. [ :model | 10]. [ :model | 10]. [ :model | 10].};
		mins: {[ :model | 1]. [ :model | 1]. [ :model | 1]. [ :model | 1]};
		roundedBorder: true;
		displayLegend: true;
		"backgroundColor: (Color red alpha: 0.5);"
		"displayLegend: true;"
		kiviatBackground: true;
		"xPadding: 20;
		yPadding: 50;"
		"defaultColor: (Color blue alpha: 0.9);"
		useColors: ESAbstractDiagram strongColorsTransparent.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/5/2012 11:38'!
kiviat2a
	"self new kiviat2a"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag kiviat)
		borderWidth: 1;
		radius: 150;
		models: {#(8 10 1). #(7 2 10). #(3 10 8)};
		metrics: {#first. #second. #last. [ :each | each first + 2]};
		maxs: {[ :model | 10]. [ :model | 10]. [ :model | 10]. [ :model | 10].};
		mins: {[ :model | 1]. [ :model | 1]. [ :model | 1]. [ :model | 1]};
		roundedBorder: true;
		"backgroundColor: (Color red alpha: 0.5);"
		displayLegend: true;
		kiviatBackground: false;
		"xPadding: 20;
		yPadding: 50;"
		"defaultColor: (Color blue alpha: 0.9);"
		useColors: ESAbstractDiagram strongColorsTransparent.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 3/18/2012 21:33'!
kiviat2b
	"self new kiviat2b"
	
	"out of the limits"
	| diag |
	diag := ESDiagramRenderer new.
	(diag kiviat)
		borderWidth: 1;
		radius: 150;
		models: {#(8 10 1). #(7 2 10). #(3 10 8)};
		metrics: {#first. #second. #last. [ :each | each first + 2]};
		maxs: {[ :model | 10]. [ :model | 10]. [ :model | 6]. [ :model | 7].};
		mins: {[ :model | 1]. [ :model | 1]. [ :model | 1]. [ :model | 1]};
		roundedBorder: true;
		"backgroundColor: (Color red alpha: 0.5);"
		"displayLegend: true;"
		kiviatBackground: true;
		"xPadding: 20;
		yPadding: 50;"
		"defaultColor: (Color blue alpha: 0.9);"
		useColors: ESAbstractDiagram strongColorsTransparent.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/1/2012 21:22'!
kiviat2c
	"self new kiviat2c"
	
	"out of the limits. TODO"
	| diag |
	diag := ESDiagramRenderer new.
	(diag kiviat)
		borderWidth: 2;
		radius: 150;
		models: {#(8 10 1). #(7 2 10). #(3 10 8)};
		metrics: {#first. #second. #last. [ :each | each first + 2]};
		maxs: {[ :model | 10]. [ :model | 10]. [ :model | 6]. [ :model | 7].};
		mins: {[ :model | 1]. [ :model | 1]. [ :model | 1]. [ :model | 1]};
		roundedBorder: false;
		"backgroundColor: (Color red alpha: 0.5);"
		"displayLegend: true;"
		kiviatBackground: true;
		"xPadding: 20;
		yPadding: 50;"
		"defaultColor: (Color blue alpha: 0.9);"
		useColors: ESAbstractDiagram strongColorsTransparent.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/5/2012 11:32'!
kiviat3
	"self new kiviat3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag kiviat)
		borderWidth: 1;
		radius: 150;
		models: {Dictionary. OrderedCollection. Collection};
		metrics: {#numberOfAttributes. [ :each | each methods size ]. #linesOfCode};
		maxs: {
			[ :model | (model collect: #numberOfAttributes) max]. 
			[ :model | (model collect: [ :each | each methods size]) max]. 
			[ :model | (model collect: #linesOfCode) max]};
		mins: {
			[ :model | 0]. 
			[ :model | 0]. 
			[ :model | 0]};
		roundedBorder: true;
		"backgroundColor: (Color red alpha: 0.5);"
		displayLegend: true;
		kiviatBackground: true;
		xPadding: 20;
		yPadding: 20;
		"defaultColor: (Color blue alpha: 0.9);"
		useColors: ESAbstractDiagram strongColorsTransparent.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2011 15:38'!
lineBarCompositeDiagram
	"self new lineBarCompositeDiagram"
	
	| diag1 factory diag2 diag3 factory2 |
	factory := ESDummyFactory new.
	factory yValues: #(30 29 25 31 28 24 22 26).
	factory2 := ESDummyFactory new.
	factory2 yValues: #(14 24 21 11 22 13 43 21).
	diag1 := (ESDiagramRenderer new lineDiagram)
		y: #yValue;
		models: factory buildDummies;
		preferredAxisMaxY: 50;
		regularAxis;
		defaultColor: Color darkGray;
		yourself.
	diag2 := (ESDiagramRenderer new verticalBarDiagram)
		y: #yValue;
		regularAxis;
		rightYAxis;
		preferredAxisMaxY: 50;
		axisColor: Color gray;
		defaultColor: Color gray;
		models: factory2 buildDummies;
		yourself.
	diag3 := ESDiagramRenderer new.
	(diag3 compositeDiagram)
		add: diag2;
		add: diag1;
		width: 400;
		height: 300.
	^ diag3 open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 5/15/2012 10:53'!
lineBarCompositeDiagram2
	"self new lineBarCompositeDiagram2"
	
	| diag1 diag2 diag3 compDiag model1 model2 model3 |
	
	model1 := #(30 29 25 31 28 24 22 26).
	model2 := #(14 24 21 11 22 13 43 21).
	model3 := #(0 20 25 14 18 12 12 15).
	
	diag1 := (ESDiagramRenderer new lineDiagram)
		y: #yourself;
		models: model1;
		regularAxis;
		"valueAxis;"
		defaultColor: Color red;
		yourself.
		
	diag2 := (ESDiagramRenderer new lineDiagram)
		y: #yourself;
		defaultColor: Color green;
		models: model2;
		yourself.
		
	diag3 := (ESDiagramRenderer new lineDiagram)
		y: #yourself;
		defaultColor: Color blue;
		models: model3;
		yourself.
		
	compDiag := ESDiagramRenderer new.
	(compDiag compositeDiagram)
		add: diag1;
		add: diag2;
		add: diag3;
		preferredAxisMaxY: 45.
	^ compDiag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 7/5/2011 16:50'!
lineBarCompositeDiagramWithSameAxis
	"self new lineBarCompositeDiagramWithSameAxis"
	
	| diag1 factory diag2 diag3 factory2 |
	factory := ESDummyFactory new.
	factory yValues: #(30 29 25 31 28 24 22 26).
	factory2 := ESDummyFactory new.
	factory2 yValues: #(14 24 21 11 22 13 43 21).
	diag1 := (ESDiagramRenderer new lineDiagram)
		y: #yValue;
		models: factory buildDummies;
		valueAxis;
		defaultColor: Color darkGray;
		yourself.
	diag2 := (ESDiagramRenderer new verticalBarDiagram)
		y: #yValue;
		axisColor: Color gray;
		defaultColor: Color gray;
		models: factory2 buildDummies;
		yourself.
	diag3 := ESDiagramRenderer new.
	(diag3 compositeDiagram)
		add: diag2;
		add: diag1;
		preferredAxisMaxY: 50;
		width: 400;
		height: 300.
	^ diag3 open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/15/2011 17:00'!
lineDiagram
	"self new lineDiagram"
		
	| diag |

	diag := ESDiagramRenderer new.
	(diag lineDiagram)
		y: #loc;
		identifier: #versionNumber;
		yAxisLabel: 'LoC';
		rotatedLabels: true;
		regularAxis;
		"valueAxis;"
		defaultColor: Color blue;
		deviationValue: (self versions collect: #loc) average;
		deviationDescription: 'average';
		preferredAxisMinY: (self versions minValue: #loc);
		models: self versions.	"startLineAtZero;"
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2011 15:25'!
lineDiagram2
	"self new lineDiagram2"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues: #(22 25 13 16 24 28 35 24 32 24 46 12).
	factory identifiers:
			#('January' 'February' 'March' 'April' 'Mai' 'June' 'July' 'August' 'September' 'October' 'November' 'December').
	diag := ESDiagramRenderer new.
	(diag lineDiagram)
		y: #yValue;
		width: 500;
		height: 400;
		lineWidth: 5;
		defaultFontSize: 12;
		identifier: #identifier;
		defaultColor: Color blue;
		yAxisLabel: 'Clients';
		regularAxis;
		deviationValue: 22;
		deviationDescription: 'avg 2006';
		rotatedLabels: true;
		models: factory buildDummies.	"startLineAtZero;"
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/9/2011 21:16'!
lineDiagram3
	"self new lineDiagram3"
	
	| diag p n |
	p := 0.6.
	n := 21.
	diag := ESDiagramRenderer new.
	(diag lineDiagram)
		y:
				[:each | 
					n factorial / ((n - each) factorial * each factorial) * (p raisedTo: each)
						* (1 - p raisedTo: n - each)];
		labels: #yourself;
		identifier: #yourself;
		defaultColor: Color red;
		valueAxis;
		lineWidth: 2;
		width: 500;
		startLineAtZero;
		models: (1 to: 21).
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/6/2011 23:25'!
matrixDiagram
	"self new matrixDiagram"
	
	| matrix diag |
	matrix := ESMalArrayMatrix withAll: #(
				   #(12 32 56 12) 
				   #(15 90 32 14) 
				   #(82 15 23 8) 
				   #(57 22 36 85)).
	diag := ESDiagramRenderer new.
	(diag matrix)
		valueBlock: #value;
		width: 500;
		height: 500;
		matrix: matrix.	

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 9/23/2011 20:55'!
matrixDiagram2
	"self new matrixDiagram2"
	
	| matrix diag |
	matrix := ESMalArrayMatrix withAll: #(
				   #(12 32 56 12) 
				   #(15 90 32 14) 
				   #(82 15 23 8) 
				   #(57 22 36 85)).
	diag := ESDiagramRenderer new.
	(diag matrix)
		valueBlock: #value;
		width: 500;
		height: 500;
		matrix: matrix;
		lowColor: Color yellow;
		highColor: Color blue.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 16:24'!
matrixDiagramInteraction1
	"self new matrixDiagramInteraction1"
	
	| matrix diag |
	matrix := ESMalArrayMatrix withAll: #(
				   #(12 32 56 12) 
				   #(15 90 32 14) 
				   #(82 15 23 8) 
				   #(57 22 36 85)).
	diag := ESDiagramRenderer new.
	(diag matrix)
		valueBlock: #value;
		width: 500;
		height: 500;
		matrix: matrix.

	diag interaction 
		strongHighlightWhenOver;
		popupText: #yourself.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/15/2011 16:33'!
matrixExample
	"self new matrixExample"
	
	| diag matrix |
	matrix := ESMalArrayMatrix
		new: 1123 @ 345
		withAll: 0.
	matrix
		doWithIndices:
			[:each :i :j | (i + j rem: 400) > 100 ifTrue: [matrix at: i and: j put: 10]].

	diag := ESDiagramRenderer new.
	(diag matrix)
		valueBlock: #yourself;
		width: 200;
		height: 200;
		matrix: matrix.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:34'!
pieDiagram1
	"self new pieDiagram1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 1;
		radius: 200;
		models: #(30 10 20 40);
		defaultColor: Color white.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:39'!
pieDiagram1interaction1
	"self new pieDiagram1interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 1;
		radius: 200;
		models: #(30 10 20 40);
		defaultColor: Color white.

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/1/2012 08:08'!
pieDiagram1interaction2
	"self new pieDiagram1interaction2"

	| diag |
	diag := ESDiagramRenderer new.
	self chartPieDiagramWithHighlightAndPopupWith: diag.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/9/2011 21:17'!
pieDiagram1interaction3
	"self new pieDiagram1interaction3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 1;
		radius: 200;
		models: #(30 10 20 40);
		defaultColor: Color white.

	diag interaction
		strongHighlightWhenOver;
		menuMorphBlock: #mooseMenuMorph.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/5/2012 11:40'!
pieDiagram2
	"self new pieDiagram2"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 1;
		radius: 200;
		models: #(30 10 20 40);
		color: #yourself.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:40'!
pieDiagram2interaction1
	"self new pieDiagram2interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 1;
		radius: 200;
		models: #(30 10 20 40);
		color: #yourself.

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/5/2012 16:46'!
pieDiagram3
	"self new pieDiagram3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 1;
		radius: 100;
		models: #(30 10 20 40);
		color: #yourself;
		displayLegend: true;
		"verticalLegend;"
		useColors: ESAbstractDiagram lightColors.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2012 18:11'!
pieDiagram3interaction1
	"self new pieDiagram3interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 1;
		radius: 100;
		displayLegend: true;
		"verticalLegend;"
		models: #(30 10 20 40);
		color: #yourself;
		useColors: ESAbstractDiagram lightColors.

	diag interaction
		strongHighlightWhenOver.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/5/2012 11:26'!
pieDiagram4
	"self new pieDiagram4"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		radius: 200;
		models: #(30 10 20 40);
		color: #yourself;
		displayLegend: true;
		useColors: ESAbstractDiagram lightColors;
		sortedAs: [ :a : b | a < b].
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:51'!
pieDiagram5
	"self new pieDiagram5"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: (1 to: 20);
		color: #yourself.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:54'!
pieDiagram5interaction1
	"self new pieDiagram5interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: (1 to: 20);
		color: #yourself.

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:51'!
pieDiagram6
	"self new pieDiagram6"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: (1 to: 100);
		color: #yourself.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:56'!
pieDiagram6interaction1
	"self new pieDiagram6interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: (1 to: 100);
		color: #yourself.

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:56'!
pieDiagram6interaction2
	"self new pieDiagram6interaction2"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: (1 to: 100);
		color: #yourself;
		useColors: (ESAbstractDiagram getTemperatureColors: 50).

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:57'!
pieDiagram6interaction3
	"self new pieDiagram6interaction3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: (1 to: 100);
		color: #yourself;
		useColors: (ESAbstractDiagram getGrayColors: 100).

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 17:07'!
pieDiagram7
	"self new pieDiagram7"
	"reducing the number of points in the arc"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: self contributors;
		pieValue: #numberOfCommits;
		color: #yourself;
		segmentEachDegree: 30.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 17:09'!
pieDiagram7interaction1
	"self new pieDiagram7interaction1"
	"reducing the number of points in the arc"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: self contributors;
		pieValue: #numberOfCommits;
		color: #yourself;
		segmentEachDegree: 30.

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 17:09'!
pieDiagram7interaction2
	"self new pieDiagram7interaction2"
	"reducing the number of points in the arc"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: self contributors;
		pieValue: #numberOfCommits;
		color: #yourself;
		segmentEachDegree: 50.

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 17:20'!
pieDiagram8
	"self new pieDiagram8"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: self contributors;
		pieValue: #numberOfCommits;
		color: #yourself.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 17:13'!
pieDiagram8interaction1
	"self new pieDiagram8interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag pieDiagram)
		borderWidth: 0;
		radius: 250;
		models: self contributors;
		pieValue: #numberOfCommits;
		color: #yourself.

	diag interaction
		strongHighlightWhenOver.
		
	^ diag open! !

!ESExamples methodsFor: 'models' stamp: 'TudorGirba 4/5/2011 22:36'!
projects
	
	| dummies1 dummies2 dummies3 historyObject LOC1 LOC2 LOC3 combination LOC4 LOC5 LOC6 dummies4 dummies5 dummies6 |
	dummies1 := ESDummyFactory new.
	dummies2 := ESDummyFactory new.
	dummies3 := ESDummyFactory new.
	dummies4 := ESDummyFactory new.
	dummies5 := ESDummyFactory new.
	dummies6 := ESDummyFactory new.
	historyObject := ESDummyFactory new.
	LOC1 := #(1 2 3 4 5 6 7 8 10 10 10 10 10 10 10 10 7 8 10 10 10 12 13 13 14 19 10).
	LOC2 := #(13 12 11 10 10 11 12 12 12 14 9 10 11 12 11 16 15 14 13 16 15 14 10 10 15 20 30).
	LOC3 := #(16 15 14 13 12 15 15 16 18 19 18 10 11 11 12 13 14 12 10 5 3 2 1 1 0 0 0).
	LOC4 := #(1 1 1 2 3 4 4 4 4 3 4 2 3 4 3 5 8 15 19 20 14 15 18 12 14 13 14).
	LOC5 := #(13 12 11 10 10 11 16 15 14 12 10 10 12 13 14 14 19 21 22 23 24 25 35 40 45 50 60).
	LOC6 := #(1 2 3 4 2 3 3 2 2 3 2 1 2 3 4 2 1 5 6 8 10 12 13 15 12 12 12).
	dummies1 yValues: LOC1.
	dummies2 yValues: LOC2.
	dummies3 yValues: LOC3.
	dummies4 yValues: LOC4.
	dummies5 yValues: LOC5.
	dummies6 yValues: LOC6.
	combination := OrderedCollection new.
	combination add: dummies1 buildDummies.
	combination add: dummies2 buildDummies.
	combination add: dummies3 buildDummies.
	combination add: dummies4 buildDummies.
	combination add: dummies5 buildDummies.
	combination add: dummies6 buildDummies.
	historyObject colors: #('Alpha' 'Beta' 'Delta' 'Epsilon' 'Gamma' 'Zeta').
	historyObject histories: combination.
	^historyObject buildDummies! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/9/2011 21:18'!
rangeDiagram
	"self new rangeDiagram"
	
	| diag models |
	models := #(#('a' 1 5) #('b' 2 9) #('c' 4 7)).
	diag := ESDiagramRenderer new.
	(diag rangeDiagram)
		identifier: #first;
		minX: #second;
		maxX: #last;
		height: 200;
		rotatedLabels: false;
		labels: #yourself;
		preferredAxisMinX: 0;
		preferredAxisMaxX: 20;
		addXDecorator: ESValueLabelDecorator new;
		models: models.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/15/2011 16:30'!
stackDiagram
	"self new stackDiagram"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag stackDiagram)
		y: #impactOnSystem;
		color: #name;
		useColors: ESAbstractDiagram lightColors;
		width: 250;
		diagramTitle: 'Participation';
		models: self contributors.	

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 4/6/2011 09:19'!
tableExample
	"self new tableExample"
	
	| diag matrix |
	matrix := Matrix new: 3.
	matrix at: 1 and: 1 put: 'Value 1@1'.
	matrix at: 1 and: 2 put: 'Value 1@2'.
	matrix at: 2 and: 2 put: 'Value 2@2'.
	matrix at: 3 and: 3 put: 'This is a bit longer'.
	diag := ESDiagramRenderer new.
	(diag table)
		models: matrix;
		height: 100;
		width: 600.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/15/2011 16:28'!
vBarDiagram5
	"self new vBarDiagram5"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		width: 300;
		height: 300;
		identifier: #name;
		y: #numberOfCommits;
		regularAxis;
		xPadding: 10;
		yPadding: 10;
		deviationDescription: 'average';
		hasMovedYAxis: true;
		hasOrientationBottomTop: false;
		hasOrientationLeftRight: true;
		models: self contributors2.	"deviationValue: 5;"		

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/6/2011 15:17'!
vBarDiagram6
	"self new vBarDiagram6"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		width: 300;
		height: 250;
		identifier: #name;
		y: #numberOfCommits;
		displayLegend: false;
		regularAxis;
		xPadding: 5;
		yPadding: 5;
		rotatedLabels: false;
		models: self contributors2.
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 16:25'!
vBarDiagram6Interaction1
	"self new vBarDiagram6Interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		width: 300;
		height: 250;
		identifier: #name;
		y: #numberOfCommits;
		displayLegend: false;
		regularAxis;
		xPadding: 5;
		yPadding: 5;
		rotatedLabels: true;
		models: self contributors2.

	diag interaction 
		strongHighlightWhenOver;
		popupText: #name.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'TudorGirba 10/2/2012 07:10'!
vBarSimple
	"self new vBarSimple"
	
	| diagram v |
	v := (1 to: 21) collect: #atRandom.
	diagram := ESDiagramRenderer new.
	(diagram verticalBarDiagram)
		y: #yourself;
		labels: #yourself;
		identifier: #yourself;
		defaultColor: Color lightGray;
		valueAxis;
		width: 500;
		deviationValue: v average;
		deviationDescription: 'average value';
		rotatedLabels: true;
		models: v.

	^ diagram open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/9/2011 21:20'!
vBarSimpleInteraction1
	"self new vBarSimpleInteraction1"
	
	| diagram |
	diagram := ESDiagramRenderer new.
	(diagram verticalBarDiagram)
		y: #yourself;
		identifier: #yourself;
		defaultColor: Color blue;
		valueAxis;
		width: 500;
		rotatedLabels: false;
		models: (1 to: 21).

	diagram interaction 
		strongHighlightWhenOver;
		popupText: #yourself.

	^ diagram open! !

!ESExamples methodsFor: 'models' stamp: 'AndreHora 12/9/2011 21:20'!
versions
	
	| versions |
	versions := OrderedCollection new.
	versions
		add:
				((ESVersion new)
						versionNumber: '1.0';
						loc: 3346);
		add:
				((ESVersion new)
						versionNumber: '1.1';
						loc: 3455);
		add:
				((ESVersion new)
						versionNumber: '1.2';
						loc: 3755);
		add:
				((ESVersion new)
						versionNumber: '1.3';
						loc: 4674);
		add:
				((ESVersion new)
						versionNumber: '1.4';
						loc: 4738);
		add:
				((ESVersion new)
						versionNumber: '1.5';
						loc: 4378);
		add:
				((ESVersion new)
						versionNumber: '1.6';
						loc: 4890);
		add:
				((ESVersion new)
						versionNumber: '1.7';
						loc: 4908);
		add:
				((ESVersion new)
						versionNumber: '1.8';
						loc: 5013).
	^ versions! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/14/2011 10:03'!
verticalBar2
	"self new verticalBar2"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues: #(25 50 19 24 35 23 28 26 24 23).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #yValue;
		regularAxis;
		width: 300;
		height: 200;
		setInvertedLinearFill;
		setColoredFill;
		models: factory buildDummies.	"or setInvertedLinearFill"
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 16:26'!
verticalBar2interaction1
	"self new verticalBar2interaction1"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues: #(25 50 19 24 35 23 28 26 24 23).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #yValue;
		regularAxis;
		width: 300;
		height: 200;
		setInvertedLinearFill;
		setColoredFill;
		models: factory buildDummies.	"or setInvertedLinearFill"
	
	diag interaction 
		strongHighlightWhenOver;
		popupText: #yValue.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 9/23/2011 21:36'!
verticalBar3
	"self new verticalBar3"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues:
			#(1 1 1 2 3 2 2 2 2 4 2 3 2 2 2 3 2 2 1 1 1 2 3 2 2 2 2 4 2 3 2 2 2 3 2 2).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #yValue;
		regularAxis;
		setLinearFill;
		height: 200;
		width: 300;
		models: factory buildDummies.	"or setInvertedLinearFill"
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 16:27'!
verticalBar3interaction1
	"self new verticalBar3interaction1"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues:
			#(1 1 1 2 3 2 2 2 2 4 2 3 2 2 2 3 2 2 1 1 1 2 3 2 2 2 2 4 2 3 2 2 2 3 2 2).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #yValue;
		regularAxis;
		setLinearFill;
		height: 200;
		width: 300;
		models: factory buildDummies.	"or setInvertedLinearFill"

	diag interaction 
		strongHighlightWhenOver;
		popupText: #yValue.	
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 9/24/2011 10:30'!
verticalBar4
	"self new verticalBar4"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues: #(25 50 19 24 35 23 28 26 24 23).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #yValue;
		regularAxis;
		width: 300;
		height: 200;
		setLinearFill;
		setColoredFill;
		displayLegend: false;
		models: factory buildDummies.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 9/23/2011 21:35'!
verticalBar5
	"self new verticalBar5"
	
	| diag factory |
	factory := ESDummyFactory new.
	factory yValues: #(25 50 19 24 35 23 28 26 24 23).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #yValue;
		regularAxis;
		width: 300;
		height: 200;
		setInvertedLinearFill;
		setColoredFill;
		displayLegend: false;
		models: factory buildDummies.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 7/5/2011 17:09'!
verticalBar7
	"self new verticalBar7"
	
	| diag factory compareValue |
	factory := ESDummyFactory new.
	compareValue := 600.
	factory yValues: #(564 132 134 2234 623 3234 340 242 265 843 2334 2500).
	factory identifiers:
			#('January' 'February' 'March' 'April' 'May' 'June' 'July' 'August' 'September' 'October' 'November' 'December').
	factory colors: #(1 1 1 2 2 3 2 3 2 4 4 1).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		identifier: #identifier;
		y: #yValue;
		height: 400;
		width: 600;
		diagramTitle: 'Customized coloring of bars';
		"axisFontSize: 20;"
		color:
				[:each "every bar above the compare value gets a different color" | each yValue > compareValue];
		rotatedLabels: true;
		displayLegend: false;
		regularAxis;
		verticalLegend;
		gridLine;
		lightColors;
		deviationValue: 2500;
		deviationDescription: 'avg 2006';
		models: factory buildDummies.	"disable legend, because it would be useless"
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 7/5/2011 17:09'!
verticalBar7interaction1
	"self new verticalBar7interaction1"
	
	| diag factory compareValue |
	factory := ESDummyFactory new.
	compareValue := 600.
	factory yValues: #(564 132 134 2234 623 3234 340 242 265 843 2334 2500).
	factory identifiers:
			#('January' 'February' 'March' 'April' 'May' 'June' 'July' 'August' 'September' 'October' 'November' 'December').
	factory colors: #(1 1 1 2 2 3 2 3 2 4 4 1).
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		identifier: #identifier;
		y: #yValue;
		height: 400;
		width: 600;
		diagramTitle: 'Customized coloring of bars';
		"axisFontSize: 20;"
		color:
				[:each "every bar above the compare value gets a different color" | each yValue > compareValue];
		rotatedLabels: true;
		displayLegend: false;
		regularAxis;
		verticalLegend;
		gridLine;
		lightColors;
		deviationValue: 2500;
		deviationDescription: 'avg 2006';
		models: factory buildDummies.	"disable legend, because it would be useless"

	diag interaction 
		strongHighlightWhenOver;
		popupText: #yValue.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/14/2011 11:19'!
verticalBarDiagram1
	"self new verticalBarDiagram1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/19/2011 10:24'!
verticalBarDiagram1interaction1
	"self new verticalBarDiagram1interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors.
	
	diag interaction
		strongHighlightWhenOver;
		popupText: #name.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/9/2011 21:23'!
verticalBarDiagram1interaction2
	"self new verticalBarDiagram1interaction2"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors.
	
	diag interaction 
		strongHighlightWhenClick 
		popupText: #name.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/19/2011 10:31'!
verticalBarDiagram1interaction3
	"self new verticalBarDiagram1interaction3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors.

	diag interaction 
		on: ESMouseDown do: [:ann | self inform: 'You clicked on the diagram, press ok!!' ];
		popupText: [ :each | 'my popup text'].
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/19/2011 11:25'!
verticalBarDiagram1interaction4
	"self new verticalBarDiagram1interaction4"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors.

	diag interaction 
		popupText: #name.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/3/2011 12:36'!
verticalBarDiagram2
	"self new verticalBarDiagram2"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		rotatedLabels: true;
		identifier: #name.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 15:54'!
verticalBarDiagram2interaction1
	"self new verticalBarDiagram2interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		rotatedLabels: true;
		identifier: #name.

	diag interaction 
		strongHighlightWhenOver;
		popupText: #name.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/19/2011 11:26'!
verticalBarDiagram2interaction2
	"self new verticalBarDiagram2interaction2"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		rotatedLabels: true;
		identifier: #name.

	diag interaction 
		popupText: #name.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/19/2011 11:28'!
verticalBarDiagram2interaction3
	"self new verticalBarDiagram2interaction3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		rotatedLabels: true;
		identifier: #name.

	diag interaction.
	
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/1/2012 21:38'!
verticalBarDiagram3
	"self new verticalBarDiagram3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		verticalLegend;
		rotatedLabels: true;
		identifier: #name;
		color: #team.
		
	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2012 18:11'!
verticalBarDiagram3interaction1
	"self new verticalBarDiagram3interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		rotatedLabels: true;
		identifier: #name;
		color: #team.
		
	diag interaction 
		strongHighlightWhenOver;
		popupText: #numberOfCommits.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 7/23/2011 22:57'!
verticalBarDiagram3interaction2
	"self new verticalBarDiagram3interaction2"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		rotatedLabels: true;
		identifier: #name;
		color: #team;
		borderWidth: 1.
		
	diag interaction 
		strongHighlightWhenOver;
		popupText: #numberOfCommits.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 10/13/2011 16:15'!
verticalBarDiagram3interaction3
	"self new verticalBarDiagram3interaction3"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		rotatedLabels: true;
		identifier: #name;
		color: #team;
		borderWidth: 3.
		
	diag interaction 
		strongHighlightWhenOver;
		popupText: #numberOfCommits.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/1/2012 15:24'!
verticalBarDiagram4
	"self new verticalBarDiagram4"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		identifier: #name;
		color: #team;
		rotatedLabels: true;
		displayLegend: true;
		"verticalLegend;"
		useColors: {Color red. Color green. Color blue}.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 15:54'!
verticalBarDiagram4interaction1
	"self new verticalBarDiagram4interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		identifier: #name;
		color: #team;
		rotatedLabels: true;
		useColors: {Color red. Color green. Color blue}.

	diag interaction 
		strongHighlightWhenOver;
		popupText: #team.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/3/2011 13:05'!
verticalBarDiagram5
	"self new verticalBarDiagram5"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		identifier: #name;
		color: #team;
		rotatedLabels: true;
		useColors: {Color red. Color green. Color blue};
		width: 190.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 15:53'!
verticalBarDiagram5interaction1
	"self new verticalBarDiagram5interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		models: self contributors;
		regularAxis;
		identifier: #name;
		color: #team;
		rotatedLabels: true;
		useColors: {Color red. Color green. Color blue};
		width: 190.

	diag interaction 
		strongHighlightWhenOver;
		popupText: #name.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/14/2011 10:02'!
verticalBarDiagram6
	"self new verticalBarDiagram6"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		regularAxis;
		identifier: #name;
		color: #team;
		gridLine;
		rotatedLabels: true;
		models: self contributors.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 4/18/2011 15:55'!
verticalBarDiagram6interaction1
	"self new verticalBarDiagram6interaction1"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #numberOfCommits;
		regularAxis;
		identifier: #name;
		color: #team;
		gridLine;
		rotatedLabels: true;
		models: self contributors.

	diag interaction 
		strongHighlightWhenOver;
		popupText: #name.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/1/2012 14:02'!
verticalBarDiagram7
	"self new verticalBarDiagram7"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag verticalBarDiagram)
		y: #yourself;
		models: #(1 2 3 4 5 6 7 8 9);
		regularAxis;
		fillColor: [ :each | 
			(each <= 3) 
				ifTrue: [Color green] 
				ifFalse: [ (each between: 4 and: 6) 
					ifTrue: [Color yellow] 
					ifFalse: [Color blue]]];
		rotatedLabels: true;
		displayLegend: false.

	^ diag open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/5/2011 15:33'!
verticalBarDiagramBounds
	"self new verticalBarDiagramBounds"
	
	| diagram |
	diagram := ESDiagramRenderer new.
	(diagram verticalBarDiagram)
		y: [:each | each];
		labels: #yourself;
		identifier: #yourself;
		defaultColor: Color red;
		regularAxis;
		width: 600;
		rotatedLabels: true;
		deviationValue: 5000;
		deviationDescription: 'average 5000';
		models: (10000 to: 10020).

	^ diagram open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 12/5/2011 15:32'!
verticalBarDiagramBounds2
	"self new verticalBarDiagramBounds2"
	
	| diagram |
	diagram := ESDiagramRenderer new.
	(diagram verticalBarDiagram)
		y: [:each | each];
		labels: #yourself;
		identifier: #yourself;
		defaultColor: Color red;
		regularAxis;
		rightYAxis;
		width: 600;
		rotatedLabels: true;
		models: (10000 to: 10020).

	^ diagram open! !

!ESExamples methodsFor: 'examples' stamp: 'AndreHora 6/6/2011 15:43'!
verticalBarDiagramSimple
	"self new verticalBarDiagramSimple"
	
	| diag |
	diag := ESDiagramRenderer new.
	(diag lineDiagram)
		y: #yourself;
		rotatedLabels;
		preferredAxisMaxY: 2;
		models: (Array with: 1 with: 2 with: 1);
		regularAxis;
		identifier: #yourself.
	  ^ diag open! !

Object subclass: #ESVersion
	instanceVariableNames: 'loc versionNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EyeSee-Tests-Core'!

!ESVersion methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
loc
	
	^loc! !

!ESVersion methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
loc: anObject
	
	loc := anObject! !

!ESVersion methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
versionNumber
	
	^versionNumber! !

!ESVersion methodsFor: 'accessing' stamp: ' 11/3/11 16:41'!
versionNumber: anObject
	
	versionNumber := anObject! !
